@@ -920,11 +920,14 @@ class GetEmailTemplateResponse(AbstractModel):
         :type TemplateContent: :class:`tencentcloud.ses.v20201002.models.TemplateContent`
         :param TemplateStatus: 模板状态 0-审核通过 1-待审核 2-审核拒绝
         :type TemplateStatus: int
+        :param TemplateName: 模板名称
+        :type TemplateName: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.TemplateContent = None
         self.TemplateStatus = None
+        self.TemplateName = None
         self.RequestId = None
 
 
@@ -933,6 +936,7 @@ class GetEmailTemplateResponse(AbstractModel):
             self.TemplateContent = TemplateContent()
             self.TemplateContent._deserialize(params.get("TemplateContent"))
         self.TemplateStatus = params.get("TemplateStatus")
+        self.TemplateName = params.get("TemplateName")
         self.RequestId = params.get("RequestId")
 
 
@@ -1973,6 +1977,51 @@ class UpdateEmailIdentityResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class UpdateEmailSmtpPassWordRequest(AbstractModel):
+    """UpdateEmailSmtpPassWord请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Password: smtp密码，长度限制64
+        :type Password: str
+        :param EmailAddress: 发信邮箱,长度限制128
+        :type EmailAddress: str
+        """
+        self.Password = None
+        self.EmailAddress = None
+
+
+    def _deserialize(self, params):
+        self.Password = params.get("Password")
+        self.EmailAddress = params.get("EmailAddress")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UpdateEmailSmtpPassWordResponse(AbstractModel):
+    """UpdateEmailSmtpPassWord返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class UpdateEmailTemplateRequest(AbstractModel):
     """UpdateEmailTemplate请求参数结构体
 
